@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -26,12 +26,18 @@ DRYRUNOPERATION = 'DryRunOperation'
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# CKafka内部错误。
+FAILEDOPERATION_CKAFKAINTERNALERROR = 'FailedOperation.CKafkaInternalError'
+
 # 调用CLS日志服务API失败
 FAILEDOPERATION_CLSDBOPERATIONFAILED = 'FailedOperation.CLSDBOperationFailed'
 
 # CLS内部错误。
 FAILEDOPERATION_CLSINTERNALERROR = 'FailedOperation.CLSInternalError'
 
+# 证书不存在
+FAILEDOPERATION_CERTIFICATENOTFOUND = 'FailedOperation.CertificateNotFound'
+
 # 操作CH数据库失败
 FAILEDOPERATION_CLICKHOUSEOPERATIONFAILED = 'FailedOperation.ClickHouseOperationFailed'
 
@@ -62,12 +68,27 @@ INTERNALERROR_ASYNCHRONOUSCALLFAILED = 'InternalError.AsynchronousCallFailed'
 # DBErr
 INTERNALERROR_DBERR = 'InternalError.DBErr'
 
+# 调用SSL证书接口发生内部错误
+INTERNALERROR_SSLCALLFAILED = 'InternalError.SSLCallFailed'
+
+# InternalError.Unknown
+INTERNALERROR_UNKNOWN = 'InternalError.Unknown'
+
 # 存在内部错误，请联系我们
 INTERNALERROR_UNKNOWNERR = 'InternalError.UnknownErr'
 
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 命名重复
+INVALIDPARAMETER_BOTNAMEREPEATERR = 'InvalidParameter.BotNameRepeatErr'
+
+# Bot场景不存在
+INVALIDPARAMETER_BOTSCENENOTEXISTERR = 'InvalidParameter.BotSceneNotExistErr'
+
+# 证书和私钥检查不通过
+INVALIDPARAMETER_CERTIFICATECHECKERR = 'InvalidParameter.CertificateCheckErr'
+
 # 证书信息参数错误
 INVALIDPARAMETER_CERTIFICATIONPARAMETERERR = 'InvalidParameter.CertificationParameterErr'
 
@@ -122,6 +143,12 @@ INVALIDPARAMETER_XFFRESETPARAMETERERR = 'InvalidParameter.XFFResetParameterErr'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 自定义规则CEL逻辑表达式长度超过10240字符
+INVALIDPARAMETERVALUE_CELLENGTHEXCEEDLIMIT = 'InvalidParameterValue.CELLengthExceedLimit'
+
+# 自定义规则CEL逻辑表达式语法错误
+INVALIDPARAMETERVALUE_CELSYNTAXERR = 'InvalidParameterValue.CELSyntaxErr'
+
 # InvalidRequest
 INVALIDPARAMETERVALUE_INVALIDREQUEST = 'InvalidParameterValue.InvalidRequest'
 
@@ -152,12 +179,18 @@ RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
+# ResourceNotFound.NotFound
+RESOURCENOTFOUND_NOTFOUND = 'ResourceNotFound.NotFound'
+
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
 # IPV6网络正在分配，请耐心等待
 RESOURCEUNAVAILABLE_DOMAINIPV6INCONFIGERR = 'ResourceUnavailable.DomainIpv6InConfigErr'
 
+# SSL证书ID关联的证书内容错误
+RESOURCEUNAVAILABLE_SSLCERTIFICATEERR = 'ResourceUnavailable.SSLCertificateErr'
+
 # 资源售罄。
 RESOURCESSOLDOUT = 'ResourcesSoldOut'
 
@@ -170,5 +203,8 @@ UNKNOWNPARAMETER = 'UnknownParameter'
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
+# Bot套餐未购买
+UNSUPPORTEDOPERATION_BOTSERVICENOTSUBSCRIBEERR = 'UnsupportedOperation.BotServiceNotSubscribeErr'
+
 # InvalidRequest
 UNSUPPORTEDOPERATION_INVALIDREQUEST = 'UnsupportedOperation.InvalidRequest'
